==> schedwisrv-0.1.3.tar.gz: schedwisrv-0.1.3/py/tables/job_arguments_s.py <==
# Schedwi
# Copyright (C) 2011 Herve Quatremain
# 
# This file is part of Schedwi.
# 
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy import Column, Integer, String, ForeignKey
from sqlalchemy.schema import ForeignKeyConstraint

from base import Base

class job_arguments_s(Base):
    __tablename__ = 'job_arguments_s'
    __table_args__ = (
            ForeignKeyConstraint(['job_id', 'workload_date'],
                                ['job_main_s.id', 'job_main_s.workload_date']),
            {})

    job_id  = Column(Integer, primary_key=True)
    job_id  = Column(Integer, primary_key=True)
    position = Column(Integer, primary_key=True)
    argument = Column(String(255))
    workload_date = Column(Integer, primary_key=True)

    def __init__(self, position, argument, workload_date):
        self.position = position
        self.argument = argument
        self.workload_date = workload_date

    def copy(self):
        return job_arguments_s(self.position, self.argument, self.workload_date)

==> schedwisrv-0.1.4.tar.gz: schedwisrv-0.1.4/py/tables/job_arguments_s.py <==
# Schedwi
# Copyright (C) 2011, 2012 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy.schema import Column, ForeignKeyConstraint
from sqlalchemy.types import Integer, String

from base import Base, convert2unicode


class job_arguments_s(Base):
    __tablename__ = 'job_arguments_s'
    __table_args__ = (
            ForeignKeyConstraint(['job_id', 'workload_date'],
                                ['job_main_s.id', 'job_main_s.workload_date']),
            {})

    job_id = Column(Integer, primary_key=True)
    position = Column(Integer, primary_key=True)
    argument = Column(String(255))
    workload_date = Column(Integer, primary_key=True)

    def __init__(self, position, argument, workload_date):
        argument = convert2unicode(argument)
        self.position = position
        self.argument = argument
        self.workload_date = workload_date

    def copy(self):
        return job_arguments_s(self.position, self.argument,
                               self.workload_date)
